@@ -36,6 +36,10 @@ public:
 	virtual	void					setWorkLoop(IOWorkLoop* inWorkLoop) {mWorkLoop = inWorkLoop; return;}					
 																
 	virtual	void					free();
+
+	virtual IOReturn				performPlatformSleep ( void );
+	virtual IOReturn				performPlatformWake ( IOService * device );
+
 	//
 	// Codec Methods
 	//
@@ -77,11 +81,15 @@ public:
 
 	virtual IOReturn				setI2SIOMIntControl(UInt32 intCntrl);
 	virtual UInt32					getI2SIOMIntControl();
+	
+	virtual IOReturn				setPeakLevel ( UInt32 channelTarget, UInt32 levelMeterValue );
+	virtual UInt32					getPeakLevel ( UInt32 channelTarget );
+	
 	//
 	// GPIO Methods
 	//
 
-	virtual void					initAudioGpioPtr ( const IORegistryEntry * start, const char * gpioName, GpioPtr* gpioH, GpioActiveState* gpioActiveStatePtr );
+	virtual void					initAudioGpioPtr ( const IORegistryEntry * start, const char * gpioName, GpioPtr* gpioH, GpioActiveState* gpioActiveStatePtr, IOService ** intProvider );
 	virtual IOReturn				getGpioPtrAndActiveState ( GPIOSelector theGpio, GpioPtr * gpioPtrPtr, GpioActiveState * activeStatePtr ) ;
 	virtual GpioAttributes			getGpioAttributes ( GPIOSelector theGpio );
 	virtual IOReturn				setGpioAttributes ( GPIOSelector theGpio, GpioAttributes attributes );
@@ -211,14 +219,14 @@ private:
 
 	volatile UInt8 *		mHwPtr;								//	remove after burning real rom on real hardware
 
-	IOService *				mHeadphoneDetectIntProvider;
-	IOService *				mSpeakerDetectIntProvider;
-	IOService *				mLineOutDetectIntProvider;								
-	IOService *				mLineInDetectIntProvider;								
-	IOService *				mDigitalOutDetectIntProvider;								
-	IOService *				mDigitalInDetectIntProvider;								
 	IOService *				mCodecIntProvider;								
 	IOService *				mCodecErrorIntProvider;								
+	IOService *				mDigitalInDetectIntProvider;								
+	IOService *				mDigitalOutDetectIntProvider;								
+	IOService *				mHeadphoneDetectIntProvider;
+	IOService *				mLineInDetectIntProvider;								
+	IOService *				mLineOutDetectIntProvider;								
+	IOService *				mSpeakerDetectIntProvider;
 
 	IOInterruptEventSource *mHeadphoneDetectIntEventSource;
 	IOInterruptEventSource *mSpeakerDetectIntEventSource;
@@ -374,6 +382,8 @@ private:
 
 	static const char*	kAmpMuteEntry;
 	static const char*  kAnalogHWResetEntry;
+	static const char*	kCodecErrorIrqTypeEntry;
+	static const char*	kCodecIrqTypeEntry;
 	static const char*  kComboInJackTypeEntry;
 	static const char*  kComboOutJackTypeEntry;
 	static const char*  kDigitalHWResetEntry;
