@@ -84,9 +84,9 @@ static const double ln2Head       = 6.9314718055994530000e-01;  /* 0x3fe62e42, 0
 static const double ln2Tail       = 2.3190468138462996000e-17;  /* 0x3c7abc9e, 0x3b39803f */
 static const double maxExp        =  7.0978271289338397000e+02; /* 0x40862e42, 0xfefa39ef */
 static const double minExp        = -7.4513321910194122000e+02; /* 0xc0874910, 0xd52d3052 */
-static const double maxExp2       =  1024.0; 
-static const double minNormExp2   = -1022.0;
-static const double minExp2       = -1075.0;
+//static const double maxExp2       =  1024.0; 
+//static const double minNormExp2   = -1022.0;
+//static const double minExp2       = -1075.0;
 static const double denormal      =  2.9387358770557188000e-39; /* 0x37f00000, 0x00000000 */
 static const double oneOverDenorm =  3.402823669209384635e+38;  /* 0x47f00000, 0x00000000 */
 static const hexdouble infinity   = HEXDOUBLE(0x7ff00000, 0x00000000);
